@@ -14,6 +14,6 @@ class TimeLogMiddleware(object):
         d = {'method': request.method, 'time': time.time() - request._start,
              'code': response.status_code,
              'url': smart_str(request.path_info)}
-        msg = '{method} "{url}" ({code}) {time:.2f}'.format(**d)
+        msg = '%(method)s "%(url)s" (%(code)s) %(time).2f' % d
         logger.info(msg)
         return response
